### load functions and R2WinBUGS
library(R2WinBUGS)

###
# Enter the location of the file, "ise calibration.R"
###

source("D:/ISE/ise calibration v21.R")


############################################
# Characterise ISE using calibration data  #
############################################

###
# Single ISE Example
###

mydata.singleISE.calibration = load.ISE.data(
		filename.calibration=
			"D:/ISE/ISE example data (calibration) ISE1.txt", 
		calibration.only=T)

example1 = characterise.ise(data = mydata.singleISE.calibration, model.path = "D:/ISE",
	model.name = "Single ISE calibration model.txt", single.ISE=T, Z = 2)

example1 = characterise.ise(data = mydata.singleISE.calibration, model.path = "D:/ISE",
	model.name = "Single ISE calibration model.txt", single.ISE=T, Z = 2,
	offset=1, sigma.upper = 9, logc.limits = c(-9.9, -1.9), keep.coda=T, coda.n = 1000)

hist(example1$LOD.SN3.coda, main="", xlab=expression(paste(LOD["S/N=3"])), breaks = seq(-8, -5.5, 0.1), freq=F )


#####
# Multiple ISE Example
#####
mydata.multipleISE.calibration = load.ISE.data(
	filename.calibration=
		"D:/ISE/ISE example data (calibration).txt", 
	calibration.only=T)

example2 = characterise.ise(data = mydata.multipleISE.calibration, model.path = "D:/ISE",
	model.name = "Multiple ISE calibration model.txt", single.ISE=F, Z = 2)

example2 = characterise.ise(data = mydata.multipleISE.calibration, model.path = "D:/ISE",
	model.name = "Multiple ISE calibration model.txt", single.ISE=F, Z = 2,
	offset=1, sigma.upper = 9, logc.limits = c(-9.9, -1.9), keep.coda=T, coda.n = 1000)


############
# Calibration and experimental data
############

###
# Single ISE Example
###
# Calibration and experimental data
mydata.SingleISE = load.ISE.data(
	filename.experimental=
		"D:/ISE/ISE example data (experimental) ISE1.txt", 
	filename.calibration=
		"D:/ISE/ISE example data (calibration) ISE1.txt")

# Run Bayesian analysis
example1 = bayesian.calibrate(mydata.SingleISE, model.path = "D:/ISE",
	model.name = "Single ISE model.txt", single.ISE=T, Z = 2)

example1.fancyplot = bayesian.calibrate(mydata.SingleISE, model.path = "D:/ISE",
	model.name = "Single ISE model.txt", single.ISE=T, Z = 2,
	plot.limits = c(-10, -4), label.x = "ID (Sample)", 
	label.y = expression(paste(log[10], " { ", italic(Pb)^{paste(2, "+")}, " }" )))


###
# Multiple ISE example
###
# Load data
mydata.MultipleISE = load.ISE.data(
	filename.experimental=
		"D:/ISE/ISE example data (experimental).txt", 
	filename.calibration=
		"D:/ISE/ISE example data (calibration).txt")

# Run Bayesian analysis
example2 = bayesian.calibrate(mydata.MultipleISE, model.path = "D:/ISE",
	model.name = "Multiple ISE model.txt", single.ISE=F, Z = 2,
	plot.limits=c(-10, -4))

###
# Standard addition example, Single ISE
###
mydata.SingleISE.sa = load.ISE.data(
	filename.experimental=
		"D:/ISE/ISE example data 2 (experimental standard addition) ISE1.txt", 
	filename.calibration=
		"D:/ISE/ISE example data 2 (calibration standard addition) ISE1.txt",
	stdadd = T)

example3 = bayesian.calibrate(mydata.SingleISE.sa, model.path = "D:/ISE", 
	model.name = "Single ISE model Standard addition.txt", stdadd = T,
	single.ISE=T, Z = 2, plot.limits = c(-7, -3))

###
# Standard addition example, Multiple ISEs
###
mydata.MultipleISE.sa = load.ISE.data(
	filename.experimental=
		"D:/ISE/ISE example data 2 (experimental standard addition).txt", 
	filename.calibration=
		"D:/ISE/ISE example data 2 (calibration standard addition).txt",
	stdadd = T)

example4 = bayesian.calibrate(mydata.MultipleISE.sa, model.path = "D:/ISE", 
	model.name = "Multiple ISE model Standard addition.txt", stdadd = T,
	single.ISE=F, Z = 2, plot.limits=c(-7, -3), sigma.upper=5)



